@@ -28,26 +28,21 @@
 #include <highscore/kscoredialog.h>
 #include <kstandardgameaction.h>
 
-#include <kaction.h>
 #include <kactioncollection.h>
 #include <kconfig.h>
 #include <kconfigdialog.h>
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kicon.h>
+#include <QIcon>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmenu.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kpushbutton.h>
 #include <kseparator.h>
 #include <kshortcutsdialog.h>
 #include <kstandardaction.h>
-#include <kstandarddirs.h>
 #include <kstandardguiitem.h>
-#include <kstatusbar.h>
+#include <qstatusbar.h>
 #include <ktoggleaction.h>
 
+#include "kshisen_debug.h"
 #include <QTimer>
 
 #include <cmath>
@@ -116,31 +111,31 @@ void App::setupActions()
     KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
     KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
 
-    KToggleAction *soundAction = new KToggleAction(KIcon(QLatin1String("speaker")), i18n("Play Sounds"), this);
+    KToggleAction *soundAction = new KToggleAction(QIcon::fromTheme(QLatin1String("speaker")), i18n("Play Sounds"), this);
     soundAction->setChecked(Prefs::sounds());
     actionCollection()->addAction(QLatin1String("sounds"), soundAction);
-    connect(soundAction, SIGNAL(triggered(bool)), m_board, SLOT(setSoundsEnabled(bool)));
+    connect(soundAction, &KToggleAction::triggered, m_board, &Board::setSoundsEnabled);
 
     // Settings
     KStandardAction::preferences(this, SLOT(showSettingsDialog()), actionCollection());
 
-    connect(m_board, SIGNAL(cheatStatusChanged()), this, SLOT(updateCheatDisplay()));
-    connect(m_board, SIGNAL(changed()), this, SLOT(updateItems()));
-    connect(m_board, SIGNAL(tilesDoNotMatch()), this, SLOT(notifyTilesDoNotMatch()));
-    connect(m_board, SIGNAL(invalidMove()), this, SLOT(notifyInvalidMove()));
-    connect(m_board, SIGNAL(selectATile()), this, SLOT(notifySelectATile()));
-    connect(m_board, SIGNAL(selectAMatchingTile()), this, SLOT(notifySelectAMatchingTile()));
-    connect(m_board, SIGNAL(selectAMove()), this, SLOT(notifySelectAMove()));
+    connect(m_board, &Board::cheatStatusChanged, this, &App::updateCheatDisplay);
+    connect(m_board, &Board::changed, this, &App::updateItems);
+    connect(m_board, &Board::tilesDoNotMatch, this, &App::notifyTilesDoNotMatch);
+    connect(m_board, &Board::invalidMove, this, &App::notifyInvalidMove);
+    connect(m_board, &Board::selectATile, this, &App::notifySelectATile);
+    connect(m_board, &Board::selectAMatchingTile, this, &App::notifySelectAMatchingTile);
+    connect(m_board, &Board::selectAMove, this, &App::notifySelectAMove);
 
     QTimer *timer = new QTimer(this);
-    connect(timer, SIGNAL(timeout()), this, SLOT(updateTimeDisplay()));
+    connect(timer, &QTimer::timeout, this, &App::updateTimeDisplay);
     timer->start(1000);
 
-    connect(m_board, SIGNAL(changed()), this, SLOT(updateTileDisplay()));
-    connect(m_board, SIGNAL(endOfGame()), this, SLOT(slotEndOfGame()));
+    connect(m_board, &Board::changed, this, &App::updateTileDisplay);
+    connect(m_board, &Board::endOfGame, this, &App::slotEndOfGame);
 
-    connect(this, SIGNAL(invokeNewGame()), m_board, SLOT(newGame()));
-    connect(m_board, SIGNAL(newGameStarted()), this, SLOT(newGame()));
+    connect(this, &App::invokeNewGame, m_board, &Board::newGame);
+    connect(m_board, &Board::newGameStarted, this, &App::newGame);
 }
 
 void App::newGame()
@@ -214,26 +209,26 @@ void App::hint()
 void App::updateItems()
 {
     if (m_board->isOver()) {
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Undo))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Redo))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Undo)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Redo)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Pause)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Hint)))->setEnabled(false);
     } else if (m_board->isPaused()) {
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Undo))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Redo))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Restart))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setChecked(true);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Undo)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Redo)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Restart)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Pause)))->setChecked(true);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Hint)))->setEnabled(false);
     } else if (m_board->isStuck()) {
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setEnabled(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Pause)))->setEnabled(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Hint)))->setEnabled(false);
     } else {
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Undo))->setEnabled(m_board->canUndo());
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Redo))->setEnabled(m_board->canRedo());
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Restart))->setEnabled(m_board->canUndo());
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setEnabled(true);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setChecked(false);
-        actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Hint))->setEnabled(true);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Undo)))->setEnabled(m_board->canUndo());
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Redo)))->setEnabled(m_board->canRedo());
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Restart)))->setEnabled(m_board->canUndo());
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Pause)))->setEnabled(true);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Pause)))->setChecked(false);
+        actionCollection()->action(QLatin1Literal(KStandardGameAction::name(KStandardGameAction::Hint)))->setEnabled(true);
     }
 }
 
@@ -252,14 +247,14 @@ void App::slotEndOfGame()
         scoreInfo[KScoreDialog::Time] = timeString;
 
         KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time | KScoreDialog::Score, this);
-        scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), "gravity");
+        scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), QLatin1Literal("gravity"));
         // FIXME: This is bad, because the translated words are stored in the highscores and thus switching the language makes ugly things (schwarzer)
         if (m_board->gravityFlag()) {
             scoreInfo[KScoreDialog::Custom1] = i18n("Yes");
         } else {
             scoreInfo[KScoreDialog::Custom1] = i18n("No");
         }
-        scoreDialog.setConfigGroup(QString("%1x%2").arg(sizeX[Prefs::size()]).arg(sizeY[Prefs::size()]));
+        scoreDialog.setConfigGroup(QString::fromLatin1("%1x%2").arg(sizeX[Prefs::size()]).arg(sizeY[Prefs::size()]));
 
         if (m_board->hasCheated()) {
             QString message = i18n("\nYou could have been in the highscores\nif you did not use Undo or Hint.\nTry without them next time.");
@@ -283,7 +278,7 @@ void App::updateTimeDisplay()
     if (m_board->isStuck() || m_board->isOver()) {
         return;
     }
-    //kDebug() << "Time: " << m_board->currentTime();
+    //qCDebug(KSHISEN_LOG) << "Time: " << m_board->currentTime();
     int currentTime = m_board->currentTime();
     QString message = i18n("Your time: %1:%2:%3 %4",
                            QString().sprintf("%02d", currentTime / 3600),
@@ -360,7 +355,7 @@ void App::setCheatModeEnabled(bool enabled)
 void App::showHighscores()
 {
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
-    scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), "gravity");
+    scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), QLatin1Literal("gravity"));
     scoreDialog.exec();
 }
 
@@ -371,21 +366,19 @@ void App::keyBindings()
 
 void App::showSettingsDialog()
 {
-    if (KConfigDialog::showDialog("settings")) {
+    if (KConfigDialog::showDialog(QLatin1Literal("settings"))) {
         return;
     }
 
     //Use the classes exposed by LibKmahjongg for our configuration dialog
-    KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, "settings", Prefs::self());
-    dialog->addPage(new Settings(0), i18n("General"), "games-config-options");
+    KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, QLatin1Literal("settings"), Prefs::self());
+    dialog->addPage(new Settings(0), i18n("General"), QLatin1Literal("games-config-options"));
     dialog->addTilesetPage();
     dialog->addBackgroundPage();
-    dialog->setHelp(QString(), "kshisen");
-    connect(dialog, SIGNAL(settingsChanged(QString)), m_board, SLOT(loadSettings()));
+    //dialog->setHelp(QString(), "kshisen");
+    connect(dialog, &KMahjonggConfigDialog::settingsChanged, m_board, &Board::loadSettings);
     dialog->show();
 }
 
-#include "app.moc"
-
 // vim: expandtab:tabstop=4:shiftwidth=4
 // kate: space-indent on; indent-width 4
